@@ -1,8 +1,11 @@
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 from mushan import shell
 from mushan import audio
 from mushan import nb
+from mushan import ml
+from mushan import dl
+from mushan import tool
 
 __all__ = [
     "__version__",
